magick_to_nr: Convert a 'magick' image to native raster image

View source: R/nr-magick.R

magick_to_nrR Documentation

Convert a 'magick' image to native raster image

Description

Convert a 'magick' image to native raster image

Usage

magick_to_nr(im, dst = NULL)

nr_to_magick(nr)

Arguments

im

image from the magick package

dst

destination native raster image. If NULL (the default) a new native raster image will be created If a native raster image is supplied here, it must have the exact dimensions to match the matrix

nr

native raster image

Value

New native raster image

See Also

Other conversion functions: matrix_to_nr(), nr_to_raster(), nrs_to_gif(), nrs_to_mp4()

Examples


im <- magick::logo
nr <- magick_to_nr(im)
plot(nr)


nara documentation built on May 28, 2026, 5:07 p.m.