nara-package: nara: Native Raster Image Tools

nara-packageR Documentation

nara: Native Raster Image Tools

Description

Native rasters are a core R image format which use a compact color representation. This color representation closely aligns with graphics device internals meaning that these images can be rendered quickly. This package provides functions to quickly create, manipulate and composite native rasters.

Author(s)

Maintainer: Mike Cheng mikefc@coolbutuseless.com [copyright holder]

Authors:

Other contributors:

  • Julien Vernay (Author of public domain code for thick polylines) [contributor]

See Also

Useful links:


nara documentation built on May 28, 2026, 5:07 p.m.