| nr_blit_multi | R Documentation |
Multiple blit operations in a single call
nr_blit_multi(dst, src, config)
dst |
destination native raster |
src |
list of native raster images. |
config |
data.frame of configuration information for each blit.
Columns in this data.frame match the arguments to
Optional columns which take a default value if not present:
|
Invisibly return the supplied dst native raster image which was been
modified in-place
Other blitting functions:
nr_blit()
nr <- nr_new(90, 90, 'grey60')
config <- data.frame(
idx = c(1, 2, 3, 4),
x = c(10, 10, 40, 40) + 15,
y = c(10, 40, 40, 10) + 15,
xsrc = 0L,
ysrc = 0L,
w = -1L,
h = -1L,
hjust = 0.5,
vjust = 0.5,
angle = c(0, 0, 0, pi/4),
scale = c(0.5, 1, 1, 1),
use_alpha = TRUE,
render = TRUE
)
nr_blit_multi(dst = nr, src = deer, config = config)
plot(nr)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.