nr_copy: Create a new native raster image and copy the dimensions and...

View source: R/nr-core.R

nr_copyR Documentation

Create a new native raster image and copy the dimensions and contents from an existing image

Description

Create a new native raster image and copy the dimensions and contents from an existing image

Usage

nr_copy(nr)

Arguments

nr

native raster image

Value

New native raster image

See Also

Other image creation functions: nr_new()

Examples

nr1 <- nr_new(200, 200, 'hotpink')
nr2 <- nr_copy(nr1)
plot(nr2)

nara documentation built on May 28, 2026, 5:07 p.m.