nr_copy_into: Copy the contents of one native raster image into another.

View source: R/nr-core.R

nr_copy_intoR Documentation

Copy the contents of one native raster image into another.

Description

The source and destination native raster images must have the same dimensions.

Usage

nr_copy_into(dst, src)

Arguments

src, dst

Source and destination native raster images

Details

If the native raster images are of different sizes or alpha blending is required, use the nr_blit() function.

Value

Invisibly return the supplied 'dst' native raster image which was been modified in-place

Examples

nr1 <- nr_new(200, 100, 'hotpink')
nr2 <- nr_new(200, 100, 'green')
nr_copy_into(nr1, nr2)
plot(nr1)

nara documentation built on May 28, 2026, 5:07 p.m.