nr_crop: Crop a section out of a native raster image into a new image

View source: R/nr-core.R

nr_cropR Documentation

Crop a section out of a native raster image into a new image

Description

Crop a section out of a native raster image into a new image

Usage

nr_crop(nr, x, y, w, h)

nr_crop2(nr, loc)

Arguments

nr

native raster image

x, y, w, h

dimensions of cropped section

loc

dimensions of cropped section. A vector of 4 values i.e. c(x, y, w, h)

Value

New native raster image

Examples

nr <- deer[[1]]
dim(nr)
plot(nr)

nr2 <- nr_crop(nr, 16, 0, 16, 16)
dim(nr2)
plot(nr2)

nara documentation built on May 28, 2026, 5:07 p.m.