nr_fill: Fill a native raster image with the given color

View source: R/nr-core.R

nr_fillR Documentation

Fill a native raster image with the given color

Description

Fill a native raster image with the given color

Usage

nr_fill(nr, color)

Arguments

nr

native raster image

color

Color as a character string. Either a standard R color (e.g. 'blue', 'white') or a hex color of the form #rrggbbaa, #rrggbb, #rgba or #rgb

Value

Invisibly return the supplied native raster image which was been modified in-place

Examples

nr <- nr_new(400, 300, 'hotpink')
nr_fill(nr, 'blue')
plot(nr)


nara documentation built on May 28, 2026, 5:07 p.m.