nr_scale: Resize a native raster image using a scale factor

View source: R/nr-scale.R

nr_scaleR Documentation

Resize a native raster image using a scale factor

Description

Resize a native raster image using a scale factor

Usage

nr_scale(nr, scale, algo = "nn")

Arguments

nr

native raster image

scale

scale factor

algo

'nn' for nearest neighbor (the default), or 'bilinear' for bilinear interpolation.

Value

New native raster image

See Also

Other resizing functions: nr_resize()

Examples

big <- deer[[1]] |> nr_scale(2)
plot(big)

nara documentation built on May 28, 2026, 5:07 p.m.