nrs_to_mp4: Convert a list of native rasters to an mp4 video file

View source: R/nr-magick.R

nrs_to_mp4R Documentation

Convert a list of native rasters to an mp4 video file

Description

Convert a list of native rasters to an mp4 video file

Usage

nrs_to_mp4(nr_list, filename, verbose = FALSE, ...)

Arguments

nr_list

list of native raster image

filename

mp4 filename

verbose

logical. default FALSE

...

other arguments passed to magick::image_write_video()

Value

None.

See Also

Other conversion functions: magick_to_nr(), matrix_to_nr(), nr_to_raster(), nrs_to_gif()

Examples


im <- magick::logo
nr1 <- magick_to_nr(im)
nr2 <- nr_copy(nr1)
nrs_to_mp4(list(nr1, nr2), "nothing.mp4")


nara documentation built on May 28, 2026, 5:07 p.m.