tileset: A list of nativeraster tiles used for constructing a...

tilesetR Documentation

A list of nativeraster tiles used for constructing a side-scrolling game.

Description

The tiles in this list are of a common base size and can be conbined to construct various scenes.

Usage

tileset

Format

An object of class list of length 44.


nara documentation built on May 28, 2026, 5:07 p.m.