Convert a 'magick' image to native raster image

magick_to_nr(im, dst = NULL)

nr_to_magick(nr)

Arguments

im

image from the magick package

dst

destination native raster image. If NULL (the default) a new native raster image will be created If a native raster image is supplied here, it must have the exact dimensions to match the matrix

nr

native raster image

Value

New native raster image

See also

Examples

if (FALSE) { # interactive() && requireNamespace("magick", quietly = TRUE)
im <- magick::logo
nr <- magick_to_nr(im)
plot(nr)
}