| magick_to_nr | R Documentation |
Convert a 'magick' image to native raster image
magick_to_nr(im, dst = NULL)
nr_to_magick(nr)
im |
image from the |
dst |
destination native raster image. If NULL (the default) a new native raster image will be created If a native raster image is supplied here, it must have the exact dimensions to match the matrix |
nr |
native raster image |
New native raster image
Other conversion functions:
matrix_to_nr(),
nr_to_raster(),
nrs_to_gif(),
nrs_to_mp4()
im <- magick::logo
nr <- magick_to_nr(im)
plot(nr)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.