Convert a numeric matrix to native raster image

matrix_to_nr(mat, palette, fill = "transparent", min = 0, max = 1, dst = NULL)

Arguments

mat

integer matrix

palette

vector of colors. For an integer matrix, this palette must contain at least as many colors as the maximum integer value in mat. For a numeric matrix, any length palette is allowed.

fill

Color to be used for values < 1 when input is an integer matrix. Default: 'transparent'.

min, max

assumed range for the numeric data. values from the palette will be interpolated using this range as the extents. An error will occur if a value lies outside this range. Default: (0, 1)

dst

destination native raster image. If NULL (the default) a new native raster image will be created If a native raster image is supplied here, it must have the exact dimensions to match the matrix

Value

native raster image

See also

Examples

m <- matrix(1:12, 3, 4)
m
#>      [,1] [,2] [,3] [,4]
#> [1,]    1    4    7   10
#> [2,]    2    5    8   11
#> [3,]    3    6    9   12
palette <- colorfast::col_to_int(rainbow(12))
nr <- matrix_to_nr(m, palette) 
plot(nr)