| matrix_to_nr | R Documentation |
Convert a numeric matrix to native raster image
matrix_to_nr(mat, palette, fill = "transparent", min = 0, max = 1, dst = NULL)
mat |
integer matrix |
palette |
vector of colors. For an integer matrix, this palette must
contain at least as many colors as the maximum integer value in |
fill |
Color to be used for values < 1 when input is an integer matrix. Default: 'transparent'. |
min, max |
assumed range for the numeric data. values from the palette will be interpolated using this range as the extents. An error will occur if a value lies outside this range. Default: (0, 1) |
dst |
destination native raster image. If NULL (the default) a new native raster image will be created If a native raster image is supplied here, it must have the exact dimensions to match the matrix |
native raster image
Other conversion functions:
magick_to_nr(),
nr_to_raster(),
nrs_to_gif(),
nrs_to_mp4()
# integer matrix
m <- matrix(1:12, 3, 4)
m
palette <- rainbow(12)
nr <- matrix_to_nr(m, palette)
plot(nr)
# numeric matrix
m <- matrix(runif(20 * 30), 20, 30)
palette <- c('red', 'blue', 'black', 'green', 'blue', 'yellow')
nr <- matrix_to_nr(m, palette)
plot(nr)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.