| nara-package | R Documentation |
Native rasters are a core R image format which use a compact color representation. This color representation closely aligns with graphics device internals meaning that these images can be rendered quickly. This package provides functions to quickly create, manipulate and composite native rasters.
Maintainer: Mike Cheng mikefc@coolbutuseless.com [copyright holder]
Authors:
Mike Cheng mikefc@coolbutuseless.com [copyright holder]
Other contributors:
Julien Vernay (Author of public domain code for thick polylines) [contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.