The source and destination native raster images must have the same dimensions.

nr_copy_into(dst, src)

Arguments

src, dst

Source and destination native raster images

Value

Invisibly return the supplied 'dst' native raster image which was been modified in-place

Details

If the native raster images are of different sizes or alpha blending is required, use the nr_blit() function.

Examples

nr1 <- nr_new(200, 100, 'hotpink')
nr2 <- nr_new(200, 100, 'green')
nr_copy_into(nr1, nr2)
plot(nr1)