The source and destination native raster images must have the same dimensions.
nr_copy_into(dst, src)Invisibly return the supplied 'dst' native raster image which was been modified in-place
If the native raster images are of different sizes or alpha blending is
required, use the nr_blit() function.