| nr_copy_into | R Documentation |
The source and destination native raster images must have the same dimensions.
nr_copy_into(dst, src)
src, dst |
Source and destination native raster images |
If the native raster images are of different sizes or alpha blending is
required, use the nr_blit() function.
Invisibly return the supplied 'dst' native raster image which was been modified in-place
nr1 <- nr_new(200, 100, 'hotpink')
nr2 <- nr_new(200, 100, 'green')
nr_copy_into(nr1, nr2)
plot(nr1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.