| nr_fill | R Documentation |
Fill a native raster image with the given color
nr_fill(nr, color)
nr |
native raster image |
color |
Color as a character string. Either a standard R color
(e.g. 'blue', 'white')
or a hex color of the form |
Invisibly return the supplied native raster image which was been modified in-place
nr <- nr_new(400, 300, 'hotpink')
nr_fill(nr, 'blue')
plot(nr)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.