A native raster image in R looks like an integer matrix, but is interpreted differently by graphics devices:

nr_new(width, height, fill = "white")

nr_new_from(nr, fill = "white")

Arguments

width, height

Image dimensions in pixels

fill

Background fill color as a character string. Either a standard R color (e.g. 'blue', 'white') or a hex color of the form #rrggbbaa, #rrggbb, #rgba or #rgb

nr

native raster image to use as the template for the size of the new image in nr_new_from()

Value

native raster image

Details

  • The data should be treated as RGBA pixels in row-major ordering

  • Each 32-bit integer should be interpreted as 4-bytes - one for each of the R, G, B and A color channels

See also

Other image creation functions: nr_copy()

Examples

nr <- nr_new(400, 300, 'hotpink')
plot(nr)