A native raster image in R looks like an integer matrix, but is interpreted differently by graphics devices:
nr_new(width, height, fill = "white")
nr_new_from(nr, fill = "white")native raster image
The data should be treated as RGBA pixels in row-major ordering
Each 32-bit integer should be interpreted as 4-bytes - one for each of the R, G, B and A color channels
Other image creation functions:
nr_copy()
nr <- nr_new(400, 300, 'hotpink')
plot(nr)